==> monica-4.0.0p0.tgz: www/monica/resources/lang/el/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Πώς ήταν η μέρα σας? Μπορείτε να αξιολογήσετε μια φορά την ημέρα.',
    'journal_come_back' => 'Ευχαριστούμε. Ελάτε αύριο για να αξιολογήσετε τη μέρα σας και πάλι.',
    'journal_description' => 'Σημείωση: το ημερολόγιο παραθέτει τόσο τις χειροκίνητες εγγραφές ημερολογίου όσο και τις αυτόματες εγγραφές όπως Δραστηριότητες που έγιναν με τις επαφές σας. Ενώ μπορείτε να διαγράψετε χειροκίνητα τις εγγραφές ημερολογίου, θα πρέπει να διαγράψετε τη Δραστηριότητα απευθείας στη σελίδα της επαφής.',
    'journal_add' => 'Προσθήκη καταχώρησης ημερολογίου',
    'journal_edit' => 'Επεξεργασία μιας καταχώρησης ημερολογίου',
    'journal_empty' => 'Κενό ημερολόγιο',
    'journal_created_at' => 'Δημιουργήθηκε στις {date}',
    'journal_created_automatically' => 'Δημιουργήθηκε αυτόματα',
    'journal_entry_type_journal' => 'Καταχώρηση ημερολογίου',
    'journal_entry_type_activity' => 'Δραστηριότητα',
    'journal_entry_rate' => 'Αξιολογήσατε την ημέρα σας.',
    'journal_add_comment' => 'Θέλετε να προσθέσετε ένα σχόλιο (προαιρετικό);',
    'journal_show_comment' => 'Προβολή σχολίων',
    'entry_delete_success' => 'Η καταχώρηση ημερολογίου έχει διαγραφεί επιτυχώς.',
    'journal_add_title' => 'Τίτλος (προαιρετικό)',
    'journal_add_date' => 'Ημερομηνία',
    'journal_add_post' => 'Καταχώριση',
    'journal_add_cta' => 'Aποθήκευση',
    'journal_blank_cta' => 'Προσθέστε την πρώτη καταχώρηση ημερολογίου',
    'journal_blank_description' => 'Το ημερολόγιο σας επιτρέπει να γράφετε γεγονότα που σας συνέβησαν και να τα θυμάστε.',
    'delete_confirmation' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτή την καταχώρηση ημερολογίου;',
];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/el/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Πώς ήταν η μέρα σας? Μπορείτε να αξιολογήσετε μια φορά την ημέρα.',
    'journal_come_back' => 'Ευχαριστούμε. Ελάτε αύριο για να αξιολογήσετε τη μέρα σας και πάλι.',
    'journal_description' => 'Σημείωση: το ημερολόγιο παραθέτει τόσο τις χειροκίνητες εγγραφές ημερολογίου όσο και τις αυτόματες εγγραφές όπως Δραστηριότητες που έγιναν με τις επαφές σας. Ενώ μπορείτε να διαγράψετε χειροκίνητα τις εγγραφές ημερολογίου, θα πρέπει να διαγράψετε τη Δραστηριότητα απευθείας στη σελίδα της επαφής.',
    'journal_add' => 'Προσθήκη καταχώρησης ημερολογίου',
    'journal_edit' => 'Επεξεργασία μιας καταχώρησης ημερολογίου',
    'journal_empty' => 'Κενό ημερολόγιο',
    'journal_created_at' => 'Δημιουργήθηκε στις {date}',
    'journal_created_automatically' => 'Δημιουργήθηκε αυτόματα',
    'journal_entry_type_journal' => 'Καταχώρηση ημερολογίου',
    'journal_entry_type_activity' => 'Δραστηριότητα',
    'journal_entry_rate' => 'Αξιολογήσατε την ημέρα σας.',
    'journal_add_comment' => 'Θέλετε να προσθέσετε ένα σχόλιο (προαιρετικό);',
    'journal_show_comment' => 'Προβολή σχολίων',
    'entry_delete_success' => 'Η καταχώρηση ημερολογίου έχει διαγραφεί επιτυχώς.',
    'journal_add_title' => 'Τίτλος (προαιρετικό)',
    'journal_add_date' => 'Ημερομηνία',
    'journal_add_post' => 'Καταχώριση',
    'journal_add_cta' => 'Aποθήκευση',
    'journal_blank_cta' => 'Προσθέστε την πρώτη καταχώρηση ημερολογίου',
    'journal_blank_description' => 'Το ημερολόγιο σας επιτρέπει να γράφετε γεγονότα που σας συνέβησαν και να τα θυμάστε.',
    'delete_confirmation' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτή την καταχώρηση ημερολογίου;',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
